@@ -24,7 +24,7 @@ from Products.ATContentTypes.content.base import registerATCT
 from Products.ATContentTypes.content.folder import ATFolderSchema, ATFolder
 from Products.ATContentTypes.configuration import zconf
 #from Products.Archetypes.public import RFC822Marshaller
-
+from Products.statusmessages.interfaces import IStatusMessage
 
 from Products.ATContentTypes.content.document import finalizeATCTSchema
 
@@ -269,7 +269,11 @@ class PFGVerkkomaksut(ATFolder, FormMailerAdapter):
 #        query = '?'+ids[0]+'='+form.get(ids[0])+''.join(queries)
         parent_url = parent.absolute_url()
         return_url = '%s/verkkomaksut-thanks' % (self.absolute_url())
-        cancel_url = '%s?portal_status_message=%s'%(parent_url, self.getCancel_message())
+#        message = 'AAA'
+#        IStatusMessage(REQUEST).addStatusMessage(message, type='info')
+#        parent.plone_utils.addPortalMessage(_(u'AAA'))
+#        cancel_url = '%s?portal_status_message=%s'%(parent_url, self.getCancel_message())
+        cancel_url = '%s/@@verkkomaksut-canceled' %(self.absolute_url())
         notify_url = '%s/verkkomaksutnotify' % (self.absolute_url())
 #        notify_url = '%s/verkkomaksutnotify%s' % (self.absolute_url(), query)
         RETURN_ADDRESS = return_url
